/*
 *
 *  PIN Dialog dialog for tdebluez authentication
 *
 *  Copyright (C) 2018  Emanoil Kotsev <deloptes@gmail.com>
 *
 *
 *  This file is part of tdebluezauth.
 *
 *  tdebluezauth is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  tdebluezauth is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with kbluetooth; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */

#ifndef PINDIALOG_H
#define PINDIALOG_H

#include <tqlineedit.h>
#include <tqlabel.h>
#include <kdialogbase.h>
#include "application.h"
#include "pindefdialog.h"

/**
@author Fred Schaettgen
 */

class PinDialog : public KDialogBase
{

    TQ_OBJECT

public:
    PinDialog(const TQString &addr, const TQString &devName);
    ~PinDialog();
    PinDefaultDialog *pinDlg;
    const TQString getPin();

private:
    TQString pin;

private slots:
    void setPin();

};

#endif
